Stan Math Library: stan/math/prim/arr/functor/integrate_ode_rk45.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
integrate_ode_rk45.hpp File Reference
`#include <stan/math/prim/arr/err/check_nonzero_size.hpp>`
`#include <stan/math/prim/arr/err/check_ordered.hpp>`
`#include <stan/math/prim/arr/functor/coupled_ode_system.hpp>`
`#include <stan/math/prim/arr/functor/coupled_ode_observer.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/err/check_less.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/invalid_argument.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <boost/numeric/odeint.hpp>`
`#include <ostream>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename F , typename T1 , typename T2 >
std::vector< std::vector< typename stan::return_type< T1, T2 >::type > > | stan::math::integrate_ode_rk45 (const F &f, const std::vector< T1 > y0, const double t0, const std::vector< double > &ts, const std::vector< T2 > &theta, const std::vector< double > &x, const std::vector< int > &x_int, std::ostream *msgs=0, double relative_tolerance=1e-6, double absolute_tolerance=1e-6, int max_num_steps=1E6)
| Return the solutions for the specified system of ordinary differential equations given the specified initial state, initial times, times of desired solution, and parameters and data, writing error and warning messages to the specified stream. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.